]> sigrok.org Git - libsigrok.git/blobdiff - sigrok.h
Add sr_ prefix for 'struct probe'.
[libsigrok.git] / sigrok.h
index 983246bb81f7366a7c7a737ddffff916ce659cd4..9518041ce32fd0bce7d05a12050fd52b5d4e04b0 100644 (file)
--- a/sigrok.h
+++ b/sigrok.h
@@ -193,7 +193,7 @@ struct sr_device {
        struct sr_device_plugin *plugin;
        /* A plugin may handle multiple devices of the same type */
        int plugin_index;
/* List of struct probe* */
        GSList *probes;
        /* Data acquired by this device, if any */
        struct datastore *datastore;
@@ -204,7 +204,7 @@ enum {
        SR_PROBE_TYPE_ANALOG,
 };
 
-struct probe {
+struct sr_probe {
        int index;
        int type;
        gboolean enabled;
@@ -193,7 +193,7 @@ struct sr_device {
        /* A plugin may handle multiple devices of the same type */
        int plugin_index;
-       /* List of struct probe* */
+       /* List of struct sr_probe* */
        GSList *probes;
        /* Data acquired by this device, if any */